#![cfg_attr(feature = "const_type_name", feature(const_type_name))]
#![cfg_attr(feature = "const_fn_panic", feature(const_panic))]

#[macro_use]
pub mod macros;

mod allocators;
mod core_types;
mod iterators;
mod limits;
mod registries;
mod tests;
mod utils;

pub use allocators::*;
pub use core_types::*;
pub use iterators::*;
pub use limits::*;
pub use registries::*;
pub use utils::*;
